| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeiatodhboj6a3p35x4f4b342lzk6ckxpud23awnqbxwjeon3k5y36u` | A protocol for ABCI requests and responses.                                                                                |
| protocol/valory/tendermint/0.1.0                              | `bafybeigydrbfrlmr4f7shbtqx44kvmbg22im27mxdap2e3m5tkti6t445y` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeifi2nri7sprmkez4rqzwb4lnu6peoy3bax5k6asf6k5ms7kmjpmkq` | A protocol specification for IPFS requests and responses.                                                                  |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeigrzbxae4t77f55qzo6gftqp3ocrfwaeofhefs32c76rmef2p7aja` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeiepywewigowj533f55orx7oys3kk5lgdc247p2267scqfyp4gnqle` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeignghdk7oqvyg722gz66tbuj2vj4vkatguj4b6lf5fqzqxkktcke4` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeicqf5y3kj42ow45hjcmnglose5n7bwpm2zl3ufuuevou24ewmgbde` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeibmqewfh5wnayopneyv4vx35n5k7loavzmcazyevntdoskw7vasom` | Service Manager contract                                                                                                   |
| contract/valory/service_registry/0.1.0                        | `bafybeidiymnku4jpw43x425igkfm7no5pmfqz26nnjwozvjhac5gmqzdcy` | Service Registry contract                                                                                                  |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeiafqx6bmocwolrdcuwe6j2xpr3lbbrrczwvki6fzwokb6diec5co4` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| contract/valory/multisend/0.1.0                               | `bafybeig5byt5urg2d2bsecufxe5ql7f4mezg3mekfleeh32nmuusx66p4y` | MultiSend contract                                                                                                         |
| contract/valory/erc20/0.1.0                                   | `bafybeib7ctk3deleyxayrqvropewefr2muj4kcqe3t3wscak25bjmxnqwe` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/service_registry_token_utility/0.1.0          | `bafybeifdia2y5546tvk6xzxeaqzf2n5n7dutj2hdzbgenxohaqhjtnjqm4` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/squads_multisig/0.1.0                         | `bafybeiccdhney6y3btaatz5gjp5kcs66d3zh2ukvxxg2d5sco23qtzguvy` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/multicall2/0.1.0                              | `bafybeiecqgtenkxyx67a7qluvpqgwcc2jzngf46qoz22626ra3pgdktmvi` | The MakerDAO multicall2 contract.                                                                                          |
| connection/valory/abci/0.1.0                                  | `bafybeihdecbtzbn6cqefssrkl4s3fzf6uyahz2uie2e6mcv2gj5vh2aaxu` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeigjspoceazd5roxo4pcqcgyu3ozixkdoc44domwcaumt2zwoz2x3m` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeiftc63rmmuik7u47uje2g43b4745sx5y6xpfh67ysbxiixdzbkmxm` | IPFS e2e testing application.                                                                                              |
| skill/valory/abstract_abci/0.1.0                              | `bafybeial2ybbl4knr5j6pcr26bqhwp24n6kkzv7ot6xup7p6tc4sgtwwna` | The abci skill provides a template of an ABCI application.                                                                 |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeigwg5fs2mmdszxtt7hzpx36xdz2xatgvnlqurwnhgrbhey4ra22c4` | abstract round-based ABCI application                                                                                      |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeifxwspkoivegwtefgpjpd5v5y5745agdiu2xwjkeh7gkcnvrnqboq` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeieqeytrq6erfs2wplnfpvcibf7dkf6wdiovj2ip3g7in7sexk7j34` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeib2uwmgzkyive53dhwnq5pvhrn7hlxndgt32gtshgiclf2xeu4x2q` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeia6okr6w6qwapt2bib3dtei67htoejbdicgeh4rvhnmfusdewyjnq` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeihn5bn26g25vie6j5qhkm7p6i3cjr6uxkkkwdz6aw323d3lan27g4` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeicrpigy4b6yscizz2lfdfbji3epny6j7rjrsngtb43vmwqxtnmi7m` | A client for the ABCI counter application.                                                                                 |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeihxk7cw32j3ezg3jfhqa52hc7srdggkxjxw4l4c7x3t3yrbspozdy` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeigyontaooxf6wvwf6ag3tbzimq264sora57eum7tefbpreqnfwwse` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeias62iw3fmieecrpulpevj6fj2ryhaqyat2zas7tmsnymmbbmkame` | ABCI application for testing the ABCI connection.                                                                          |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeia4vgvxtepqxiuw6k6z5imwm5j2zlf73l73ekvxb5jtfbu23dkhga` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/slashing_abci/0.1.0                              | `bafybeibkxnakg33jgqrjyz4p2jjiajzxitbsv4jvxemmz3vyumecarokge` | Slashing skill.                                                                                                            |
| skill/valory/offend_abci/0.1.0                                | `bafybeihwayjpwt5gdflo4tmwtumha6jycrocrgxvdiusjg64avgkguhuca` | Offend ABCI application.                                                                                                   |
| skill/valory/offend_slash_abci/0.1.0                          | `bafybeic3zwxydaav2zy6tkzgbqchummajhibxegjelcdwwzkr3mpydcxiu` | ABCI application used in order to test the slashing abci                                                                   |
| skill/valory/squads_transaction_settlement_abci/0.1.0         | `bafybeicz5gyo6pckt2oqhaou6jpzlw3lj2zgb66z7owwhpj5iqn2netzie` | ABCI application for transaction settlement.                                                                               |
| skill/valory/test_solana_tx_abci/0.1.0                        | `bafybeigma2iytdffwnbdvwa2gp3ufgrax3ylneo7du2ztjzpdeo2lee344` | SOLANA e2e testing application.                                                                                            |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeidriyizb3uo37nttxptxblml2j5ttxgkiism4prk3wsxfjlmqn2ou` | Agent for testing the ABCI connection.                                                                                     |
| agent/valory/abstract_abci/0.1.0                              | `bafybeiezcias5aa7zcdzwtwyqqocgb5itkmm665fyzdac3pzhxq5gbvmgi` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeic2pwdncqwvxmqupqsfr4euwvu3hqf4mtgaa7wykt5en2vfkpnham` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeihfgb3aga3t5mcyw5clnaezi25lujsufxdnttoyflrikgkilec4pa` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/register_reset/0.1.0                             | `bafybeidkw57sl6o75zocr6clswa6dzbnp7627lbnpqjpgdoc4cmkm4yszu` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeifxjxhd7lex4aahazs7mr3rlu2b5tbt3ww6uzkhysyt5o2nfml2tq` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeihlvr25nqjiebskeycjq3mfopsunim3kb5dqqkdv5efq27qmk7p3i` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeiceedl5jwyrc54ilo3pbwuguune566eeqvsxparppq6xzp2igaqye` | Agent for testing the ABCI connection.                                                                                     |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeig262uqv7np65pmktorkqk4ejkshgd66upakcipcfz7fcg5v5fksi` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| agent/valory/offend_slash/0.1.0                               | `bafybeidnxzlek4gf54r763iwh44dfmaotopnkoezgmt2qdf4s46cru76m4` | Offend and slash to test the slashing feature.                                                                             |
| agent/valory/solana_transfer_agent/0.1.0                      | `bafybeihi27rlvqqvuf5bak3s75bov3vfywxgx545luzdnzt5uprhg7aroi` | Register terminate to test the termination feature.                                                                        |
| service/valory/counter/0.1.0                                  | `bafybeidznh5uv4zggujm36crge7n2puberavgt2dhuezt4e5z7a267yy2m` | A set of agents incrementing a counter                                                                                     |
| service/valory/register_reset/0.1.0                           | `bafybeih4ht7d262k4txdpuun4jb5jgdt5o2unio6y7xs7kavr4y6qzufzy` | Test and debug tendermint reset mechanism.                                                                                 |
| protocol/open_aea/signing/1.0.0                               | `bafybeig2d36zxy65vd7fwhs7scotuktydcarm74aprmrb5nioiymr3yixm` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeic6h55ov5lrzbah6fate54c4u6spopcexxspw3abotbmffabfddeu` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeih4azmfwtamdbkhztkm4xitep3gx6tfdnoz6tvllmaqnhu3klejfa` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeihmqzcbj6t7vxz2aehd5726ofnzsfjs5cwlf42ro4tn6i34cbfrc4` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeid247uig2ekykdumh7ewhp2cdq7rchaeqjj6e7urx35zfpdl5zrn4` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeid5ffvg76ejjoese7brj5ji3lx66cu7p2ixfwflpo6rgofkypfd7y` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeibiayfscw4badpr545f47hsvc2r5lgfpgzib5q4h4u6kkosdsytby` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeic6ayusdwy4dks75njwk32ac7ur7salgllwf4fdc34ue5z2k5iz4q` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
